==> qmmp-0.6.4.tar.bz2: qmmp-0.6.4/src/app/translations/qmmp_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="68"/>
        <source>Skip forward in playlist</source>
        <translation>Nächsten Titel in Wiedergabeliste abspielen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="69"/>
        <source>Skip backwards in playlist</source>
        <translation>Vorherigen Titel in Wiedergabeliste abspielen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="61"/>
        <source>Start playing current song</source>
        <translation>Aktuellen Titel abspielen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="60"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Titel an Wiedergabeliste anhängen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="62"/>
        <source>Pause current song</source>
        <translation>Aktuellen Titel anhalten</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="63"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Wiedergabe anhalten oder fortsetzen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="64"/>
        <source>Stop current song</source>
        <translation>Aktuellen Titel stoppen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="65"/>
        <source>Display Jump to File dialog</source>
        <translation>„Springe zu Titel“-Dialog anzeigen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="66"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="67"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Lautstärke der Wiedergabe einstellen (Beispiel: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="70"/>
        <source>Show/hide application</source>
        <translation>Anwendung ein-/ausblenden</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Display Add File dialog</source>
        <translation>„Datei hinzufügen“-Dialog anzeigen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Display Add Directory dialog</source>
        <translation>„Verzeichnis hinzufügen“-Dialog anzeigen</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="287"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Aufruf: qmmp [Optionen] [Dateien]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="288"/>
        <source>Options:</source>
        <translation>Optionen:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="292"/>
        <source>Don&apos;t start the application</source>
        <translation>Die Anwendung nicht starten</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="294"/>
        <source>Print version number and exit</source>
        <translation>Gibt die Versionsnummer aus</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="295"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Ideen, Patches und Bugreports an &lt;forkotov02@hotmail.ru&gt; senden</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="300"/>
        <source>QMMP version: %1</source>
        <translation>Qmmp-Version: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="301"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Kompiliert mit der Qt-Version %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="302"/>
        <source>Using Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="293"/>
        <source>Display this text and exit</source>
        <translation>Zeigt diesen Hilfetext an</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="83"/>
        <source>Unknown command</source>
        <translation>Unbekannter Befehl</translation>
    </message>
</context>
</TS>

==> qmmp-0.8.0.tar.bz2: qmmp-0.8.0/src/app/translations/qmmp_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Skip forward in playlist</source>
        <translation>Nächsten Titel in Wiedergabeliste abspielen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Skip backwards in playlist</source>
        <translation>Vorherigen Titel in Wiedergabeliste abspielen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Aktuellen Titel abspielen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Titel an Wiedergabeliste anhängen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Aktuellen Titel anhalten</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Wiedergabe anhalten oder fortsetzen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Aktuellen Titel stoppen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>„Springe zu Titel“-Dialog anzeigen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Lautstärke der Wiedergabe einstellen (Beispiel: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Mute/Restore volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Show/hide application</source>
        <translation>Anwendung ein-/ausblenden</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Show main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Display Add File dialog</source>
        <translation>„Datei hinzufügen“-Dialog anzeigen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Display Add Directory dialog</source>
        <translation>„Verzeichnis hinzufügen“-Dialog anzeigen</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="304"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Aufruf: qmmp [Optionen] [Dateien]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="305"/>
        <source>Options:</source>
        <translation>Optionen:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="309"/>
        <source>Don&apos;t start the application</source>
        <translation>Die Anwendung nicht starten</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="311"/>
        <source>Print version number and exit</source>
        <translation>Gibt die Versionsnummer aus</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="312"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Ideen, Patches und Bugreports an &lt;forkotov02@hotmail.ru&gt; senden</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="315"/>
        <source>Command Line Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="328"/>
        <source>QMMP version: %1</source>
        <translation>Qmmp-Version: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="329"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Kompiliert mit der Qt-Version %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="330"/>
        <source>Using Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="333"/>
        <source>Qmmp Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="310"/>
        <source>Display this text and exit</source>
        <translation>Zeigt diesen Hilfetext an</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="90"/>
        <source>Unknown command</source>
        <translation>Unbekannter Befehl</translation>
    </message>
</context>
</TS>
